;; Generated package description from url-http-oauth.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "url-http-oauth" "0.8.3.0.20250314.122034" "OAuth 2.0 for URL library" '((emacs "24.4")) :commit "7c415002dd34e46f23a944acca738c3ec19d6808" :url "https://elpa.gnu.org/packages/url-http-oauth.html" :authors '(("Thomas Fitzsimmons" . "fitzsim@fitzsim.org")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("comm" "data" "processes" "hypermedia"))
